@@ -79,7 +79,7 @@ void updatedb(string db)
 
 bool myglob(string file, string glob )
 {
-	bool debug = getenv("DEBUG") != NULL;
+	bool debug = getenv("DEBUG_GLOB") != NULL;
 
 	if (file==glob) return true;
 	unsigned int filesize=file.size();
@@ -114,60 +114,6 @@ bool myglob(string file, string glob )
 	}
 }
 
-bool pyc_has_py(string pyc)
-{
-	if (pyc.length() < 15)
-		return false;
-
-	// #366616: Don't report .pyc files if a .py file exist
-
-	// also ignore __pycache__ dirs
-	// if .py are found in the same directory
-	if (pyc.substr(pyc.length()-12, 12) == "/__pycache__") {
-		DIR *dp;
-		struct dirent *dirp;
-		if((dp = opendir(pyc.substr(0, pyc.length()-12).c_str())) == NULL) {
-		      return false;
-		}
-		while ((dirp = readdir(dp)) != NULL) {
-			string entry = dirp->d_name;
-			if (entry.length() < 4)
-				continue;
-			if (entry.substr(entry.length()-3,3) == ".py")
-				return true;
-		}
-		return false;
-	}
-
-	/* scenario 1:
-	/usr/share/python/debpython/debhelper.py
-	/usr/share/python/debpython/debhelper.pyc
-	*/
-	if (pyc.substr(pyc.length()-4, 4) != ".pyc")
-		return false;
-
-	struct stat buffer;
-	if (stat(pyc.substr(0, pyc.length()-1).c_str(), &buffer) == 0)
-		return true;
-
-	/* scenario 2:
-	/usr/share/pgcli/pgcli/packages/counter.py
-	/usr/share/pgcli/pgcli/packages/__pycache__/counter.cpython-34.pyc
-	*/
-	size_t pos = pyc.find("/__pycache__/");
-	if (pos == string::npos)
-		return false;
-	pyc.replace(pos, 13, "/");
-
-	pos = pyc.find(".cpython-");
-	if (pos == string::npos)
-		return false;
-	int ugly=0; if(pyc.find(".cpython-310") != string::npos) ugly=1;
-	pyc.replace(pos, 15+ugly, ".py");
-
-	return stat(pyc.c_str(), &buffer) == 0;
-}
-
 void one_file(string infile)
 {
 	char* file=realpath(infile.c_str(), NULL);
@@ -195,6 +141,8 @@ void one_file(string infile)
 			if (glob_file.eof()) break;
 		}
 	}
+	closedir(dp);
+
 	if (not matched) cerr << "no matching package found" << endl;
 }
 
@@ -246,7 +194,8 @@ int main(int argc, char *argv[])
 	cout << "cruft report: " << buf << endl << flush;
 
 	std::vector<string> packages;
-	read_dpkg_header(packages);
+	std::vector<string> dpkg;
+	read_dpkg(packages, dpkg);
 
 	std::vector<string> explain;
 	read_explain(packages,explain);
@@ -254,9 +203,6 @@ int main(int argc, char *argv[])
 	std::vector<string> globs;
 	read_filters(packages,globs);
 
-	std::vector<string> dpkg;
-	read_dpkg_items(dpkg);
-
 	std::vector<string> excludes;
 	read_dpkg_excludes(excludes);
 
@@ -275,10 +221,7 @@ int main(int argc, char *argv[])
 			cruft.push_back(*left);
 			left++;
 		} else {
-			// file may exist on tmpfs
-			// e.g.: /var/cache/apt/archives/partial
-			struct stat stat_buffer;
-	                if ( stat((*right).c_str(), &stat_buffer)!=0 && *right != "/.") missing.push_back(*right);
+			missing.push_back(*right);
 			right++;
 		}
 		if (right == dpkg.end()) while(left  !=fs.end()  ) {cruft.push_back(*left);    left++; };
@@ -293,6 +236,7 @@ int main(int argc, char *argv[])
 	// https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=619086
 	vector<string> missing2;
 	left=missing.begin();
+	int count_stat = 0;
 	while (left != missing.end()) {
 		right=excludes.begin();
 		bool match=false;
@@ -301,49 +245,25 @@ int main(int argc, char *argv[])
 			if (match) break;
 			right++;
 		}
-		if (!match) missing2.push_back(*left);
+		if (!match) {
+			// file may exist on tmpfs
+			// e.g.: /var/cache/apt/archives/partial
+			struct stat stat_buffer;
+	                if ( stat((*left).c_str(), &stat_buffer) == 0) {
+				count_stat += 1;
+				if (debug) cerr << *left << " was not in plocate database" << endl;
+			} else {
+				missing2.push_back(*left);
+			};
+		}
 		left++;
 	}
-
-	// TODO: this should use DPKG database too
-	vector<string> cruft2;
-	left=cruft.begin();
-	right=packages.begin();
-	while (left != cruft.end()) {
-		if ((*left).substr(0,19) !=  "/var/lib/dpkg/info/") {
-			cruft2.push_back(*left);
-			left++;
-		} else {
-			right=packages.begin();
-			bool found=false;
-			while(right != packages.end() ) {
-			    if ( *left=="/var/lib/dpkg/info/" + *right + ".clilibs"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".conffiles"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".config"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".list"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".md5sums"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".postinst"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".postrm"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".preinst"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".prerm"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".shlibs"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".symbols"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".templates"
-			      or *left=="/var/lib/dpkg/info/" + *right + ".triggers")
-				{ found=true; break; }
-				right++;
-			}
-			if (!found) cruft2.push_back(*left);
-			left++;
-		}
-	}
-	//cruft.clear();
-	if (debug) cerr << cruft2.size() << " files in cruft2 database" << endl << endl << std::flush;
+	if (debug) cerr << "count stat():" << count_stat << endl;
 
 	// match the globs against reduced database
 	vector<string> cruft3;
-	left=cruft2.begin();
-	while (left != cruft2.end()) {
+	left=cruft.begin();
+	while (left != cruft.end()) {
 		right=globs.begin();
 		bool match=false;
 		while (right != globs.end()) {
@@ -384,8 +304,7 @@ int main(int argc, char *argv[])
 	//TODO: split by filesystem
 	cout << "---- unexplained: / ----" << endl;
 	for (unsigned int i=0;i<cruft4.size();i++) {
-		if (!pyc_has_py(cruft4[i]))
-			cout << "        " << cruft4[i] << endl;
+		cout << "        " << cruft4[i] << endl;
 	}
 
 	// NOT IMPLEMENTED
