@@ -10,7 +10,7 @@
 
 void read_one_filter(const string& glob_filename, vector<string>& globs)
 {
-	bool debug=getenv("DEBUG") != NULL;
+	bool debug=getenv("DEBUG_RULES") != NULL;
 
 	if (debug) cerr << "READING " << glob_filename << endl;
 	ifstream glob_file(glob_filename.c_str());
@@ -46,6 +46,7 @@ int read_filters(/* const */ vector<string>& packages, vector<string>& globs)
 		if (package==uppercase)
 			read_one_filter("/etc/cruft/filters/" + package, globs);
 	}
+	closedir(dp);
 	if (debug) cerr << endl;
 
 
