@@ -6,6 +6,7 @@
 #include <limits.h>
 
 #include "plocate.h"
+#include "python.h"
 
 // build fail on hurd-i386
 #ifndef PATH_MAX
@@ -19,7 +20,7 @@ int read_plocate(vector<string>& fs, vector<string>& prunefs)
 	string line;
 
 	if (debug) cerr << "PLOCATE DATA\n";
-	string command = "plocate .";
+	string command = "plocate /";
         char buf[PATH_MAX];
         FILE* fp;
         if ((fp = popen(command.c_str(), "r")) == NULL) return 1;
@@ -34,7 +35,7 @@ int read_plocate(vector<string>& fs, vector<string>& prunefs)
 		    or toplevel == "/root"
 		    or toplevel == "/tmp")
 			continue;
-		fs.push_back(filename);
+		if (!pyc_has_py(filename, false)) fs.push_back(filename);
 	}
 	pclose(fp);
 	sort(fs.begin(), fs.end());
