@@ -3,8 +3,14 @@
 
 int main(int argc, char *argv[])
 {
+	vector<string> packages;
 	vector<string> db;
-	read_dpkg_items(db);
+	read_dpkg(packages, db);
+
+	for (unsigned int i=0;i<packages.size();i++) {
+		cout << packages[i] << endl;
+	}
+	cout << endl;
 
 	cout << '/' << endl;
 	for (unsigned int i=0;i<db.size();i++) {
